@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,9 +22,7 @@ ImportImapSettingProgressPage::ImportImapSettingProgressPage(QWidget *parent)
     mainLayout->addWidget(mProgressTextEdit);
 }
 
-ImportImapSettingProgressPage::~ImportImapSettingProgressPage()
-{
-}
+ImportImapSettingProgressPage::~ImportImapSettingProgressPage() = default;
 
 void ImportImapSettingProgressPage::addProgressInfo(const QString &str)
 {
