@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ SieveEditorManageSieveWidget::SieveEditorManageSieveWidget(QWidget *parent)
 {
 }
 
-SieveEditorManageSieveWidget::~SieveEditorManageSieveWidget()
-{
-}
+SieveEditorManageSieveWidget::~SieveEditorManageSieveWidget() = default;
 
 bool SieveEditorManageSieveWidget::refreshList()
 {
